@@ -10,7 +10,7 @@ from switcore.auth.signature_verification import SignatureVerifier
 async def get_swit_request(
         request: Request,
 ):
-    swit_singing_key: str = os.getenv('SWIT_SINGING_KEY', None)
+    swit_singing_key: str | None = os.getenv('SWIT_SINGING_KEY', None)
 
     assert swit_singing_key is not None, "SWIT_SINGING_KEY is not set check .env file"
 
