@@ -15,16 +15,16 @@ class BaseModel(base_model):
 class App(BaseModel):
     __tablename__ = 'app'
 
-    access_token = Column(String(500))
-    refresh_token = Column(String(50))
-    iss = Column(String(50))
-    cmp_id = Column(String(50), nullable=True)
-    apps_id = Column(String(50))
+    access_token: str = Column(String(500))
+    refresh_token: str = Column(String(50))
+    iss: str = Column(String(50))
+    cmp_id: str = Column(String(50), nullable=True)
+    apps_id: str = Column(String(50))
 
 
 class User(BaseModel):
     __tablename__ = 'user'
 
-    swit_id = Column(String(100))
-    access_token = Column(String(500))
-    refresh_token = Column(String(50))
+    swit_id: str = Column(String(100))
+    access_token: str = Column(String(500))
+    refresh_token: str = Column(String(50))
