@@ -13,6 +13,9 @@ class SignatureVerifier:
         if None in [body, timestamp_or_null, signature_or_null]:
             return False
 
+        assert signature_or_null is not None, "signature_or_null is None"
+        assert timestamp_or_null is not None, "timestamp_or_null is None"
+
         if self._is_timestamp_valid(timestamp_or_null):
             calculated_signature = self._generate_signature(body, timestamp_or_null)
             return hmac.compare_digest(calculated_signature, signature_or_null)
