@@ -4,7 +4,7 @@ from switcore.constants import Environment
 
 
 def get_swit_openapi_base_url() -> str:
-    env: str = os.getenv('ENV_OPERATION', None)
+    env: str | None = os.getenv('ENV_OPERATION', None)
 
     assert env is not None, "ENV_OPERATION is not set check .env file"
 
