@@ -5,7 +5,7 @@ import httpx
 
 
 async def set_translate():
-    localise_token: str = os.getenv('LOCALIZE_PROJECT_ID', None)
+    localise_token: str | None = os.getenv('LOCALIZE_PROJECT_ID', None)
 
     assert localise_token is not None, "LOCALIZE_PROJECT_ID is not set check .env file"
 
