@@ -1,12 +1,11 @@
 from typing import Optional
 
-from pydantic import BaseModel
-
+from switcore.pydantic_base_model import SwitBaseModel
 from switcore.ui.Icon import Icon
 from switcore.ui.element_components import StaticAction
 
 
-class Button(BaseModel):
+class Button(SwitBaseModel):
     id: Optional[str] = None
     type: str = "button"
     label: str | None = None
