@@ -1,13 +1,12 @@
 from enum import Enum
 
-from pydantic import BaseModel
-
+from switcore.pydantic_base_model import SwitBaseModel
 from switcore.ui.element_components import SubText, Tag, StaticAction
 from switcore.ui.image import Image
 from switcore.ui.text_paragraph import TextParagraph
 
 
-class TextStyle(BaseModel):
+class TextStyle(SwitBaseModel):
     bold: bool = False
     color: str
     size: str
@@ -19,20 +18,20 @@ class BackgroundType(str, Enum):
     lightblue = "lightblue"
 
 
-class Background(BaseModel):
+class Background(SwitBaseModel):
     color: BackgroundType = BackgroundType.none
 
 
-class MetadataItem(BaseModel):
+class MetadataItem(SwitBaseModel):
     type: str
-    content: str | None
-    style: dict | None
-    image_url: str | None
+    content: str | None = None
+    style: dict | None = None
+    image_url: str | None = None
 
 
-class TextSection(BaseModel):
+class TextSection(SwitBaseModel):
     text: TextParagraph
-    metadata_items: list[SubText | Image | Tag] | None
+    metadata_items: list[SubText | Image | Tag] | None = None
 
 
 class VerticalAlignmentTypes(str, Enum):
@@ -41,12 +40,12 @@ class VerticalAlignmentTypes(str, Enum):
     bottom = "bottom"
 
 
-class CollectionEntry(BaseModel):
+class CollectionEntry(SwitBaseModel):
     type: str = "collection_entry"
-    start_section: Image | None
+    start_section: Image | None = None
     text_sections: list[TextSection]
     vertical_alignment: VerticalAlignmentTypes = VerticalAlignmentTypes.top
-    background: Background | None
-    action_id: str | None
-    static_action: StaticAction | None
+    background: Background | None = None
+    action_id: str | None = None
+    static_action: StaticAction | None = None
     draggable: bool = False
