@@ -1,6 +1,6 @@
-from pydantic import BaseModel
 from enum import Enum
 
+from switcore.pydantic_base_model import SwitBaseModel
 from switcore.ui.element_components import StaticAction
 
 
@@ -42,7 +42,7 @@ def get_file_type(file_extension: str) -> FileTypes:
     return file_type
 
 
-class File(BaseModel):
+class File(SwitBaseModel):
     type: str = "file"
     file_type: FileTypes
     file_size: int
