@@ -1,7 +1,7 @@
-from pydantic import BaseModel
+from switcore.pydantic_base_model import SwitBaseModel
 
 
-class Image(BaseModel):
+class Image(SwitBaseModel):
     type: str = "image"
     image_url: str
     alt: str | None = None
