@@ -1,6 +1,6 @@
 from enum import Enum
 
-from pydantic import BaseModel
+from switcore.pydantic_base_model import SwitBaseModel
 
 
 class InputVariant(str, Enum):
@@ -8,7 +8,7 @@ class InputVariant(str, Enum):
     select = 'select'
 
 
-class Input(BaseModel):
+class Input(SwitBaseModel):
     type: str = 'text_input'
     action_id: str
     placeholder: str | None
