@@ -1,7 +1,7 @@
-from pydantic import BaseModel
+from switcore.pydantic_base_model import SwitBaseModel
 from switcore.ui.text_paragraph import TextParagraph
 
 
-class Item(BaseModel):
+class Item(SwitBaseModel):
     label: str
     text: TextParagraph
