@@ -1,7 +1,7 @@
-from pydantic import BaseModel
+from switcore.pydantic_base_model import SwitBaseModel
 
 
-class SearchInput(BaseModel):
+class SearchInput(SwitBaseModel):
     type: str = 'search_input'
     action_id: str
     placeholder: str | None
