@@ -1,9 +1,8 @@
-from pydantic import BaseModel
-
+from switcore.pydantic_base_model import SwitBaseModel
 from switcore.ui.select_item import SelectItem
 
 
-class Tabs(BaseModel):
+class Tabs(SwitBaseModel):
     """
         An element representing an array of tabs.
     """
