@@ -1,6 +1,8 @@
 from enum import Enum
 
-from pydantic import BaseModel, validator
+from pydantic import validator
+
+from switcore.pydantic_base_model import SwitBaseModel
 
 
 class TextParagraphColorTypes(str, Enum):
@@ -14,7 +16,7 @@ class TextParagraphSizeTypes(str, Enum):
     large = "large"
 
 
-class TextParagraphStyle(BaseModel):
+class TextParagraphStyle(SwitBaseModel):
     bold: bool = False
     color: TextParagraphColorTypes = TextParagraphColorTypes.gray900
     size: TextParagraphSizeTypes = TextParagraphSizeTypes.medium
@@ -27,7 +29,7 @@ class TextParagraphStyle(BaseModel):
         return v
 
 
-class TextParagraph(BaseModel):
+class TextParagraph(SwitBaseModel):
     type: str = "text"
     markdown: bool = False
     content: str
