@@ -1,18 +1,18 @@
 from enum import Enum
 
-from pydantic import BaseModel
+from switcore.pydantic_base_model import SwitBaseModel
 
 
-class SizeTypes(str, Enum):
+class TextareaSizeTypes(str, Enum):
     small = "small"
     medium = "medium"
     large = "large"
 
 
-class Textarea(BaseModel):
+class Textarea(SwitBaseModel):
     type: str = "textarea"
     action_id: str
     placeholder: str | None
     value: str | None
-    height: SizeTypes
+    height: TextareaSizeTypes = TextareaSizeTypes.small
     disabled: bool = False
